<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

defined('_JEXEC') or die;

/**
 * UnaApi component helper.
 *
 * @since  1.6
 */
class UnaApiHelper extends JHelperContent
{
	/**
	 * Configure the Linkbar.
	 *
	 * @param   string  $vName  The name of the active view.
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	public static function addSubmenu($vName)
	{
		JHtmlSidebar::addEntry(
			JText::_('COM_UNAAPI'),
			'index.php?option=com_unaapi',
			$vName == 'unaapi'
		);
	}

	/**
	 * Make image path safe - remove anchor and special characters in file name
	 *
	 * @param   string  $path  File path
	 *
	 * @return  string  safe file path
	 *
	 */
	public static function imgSafe(string $path)
	{
		// strip anchor
		list($path) = explode('#', $path);

		// URL encode file name
		$parts = explode('/', $path);
		$file_name = end($parts);
		$safe_file_name = urlencode($file_name);
		$parts[count($parts)-1] = $safe_file_name;

		return implode('/', $parts);
	}

	/**
	 * Replace replative paths in the text with absolute
	 *
	 * @param   string  $html  HTML string
	 *
	 * @return  string  fixed HTML string
	 *
	 */
	public static function sef($html) {

		$base   = JUri::base() . '/';

		$html = trim($html);

		// Check for all unknown protocols (a protocol must contain at least one alphanumeric character followed by a ":").
		$protocols  = '[a-zA-Z0-9\-]+:';
		$attributes = array('href=', 'src=', 'poster=');

		foreach ($attributes as $attribute) {
			if (strpos($html, $attribute) !== false) {
				$regex  = '#\s' . $attribute . '"(?!/|' . $protocols . '|\#|\')([^"]*)"#m';
				$html = preg_replace($regex, ' ' . $attribute . '"' . $base . '$1"', $html);
			}
		}

		return $html;
	}
}