<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

defined('_JEXEC') or die;

class UnaApiModelUnaApi extends JModelLegacy
{
	protected $params = null;

	protected $algo = 'sha256';
	protected $tokenLength = 32;

	public function __construct($config = array())
	{
		$this->params = JComponentHelper::getParams('com_unaapi');

		parent::__construct($config);
	}

	/**
	 * Get Token for display
	 *
	 * @return  string  Token for display
	 *
	 * @since   2.5
	 */
	public function getTokenForDisplay() {
		$params = $this->params;

		$tokenSeed = $params->get('token', '');

		if (empty($tokenSeed)) {
			return '';
		}

		$algorithm = $this->algo;

		try {
			$siteSecret = JFactory::getApplication()->get('secret');
		} catch (\Exception $e) {
			$siteSecret = '';
		}

		if (empty($siteSecret)) {
			return '';
		}

		$rawToken  = base64_decode($tokenSeed);
		$tokenHash = hash_hmac($algorithm, $rawToken, $siteSecret);
		$message   = base64_encode("$algorithm:$tokenHash");

		return $message;
	}

	public function createNewToken() {

		$token = base64_encode(JCrypt::genRandomBytes($this->tokenLength));

		$db = JFactory::getDbo();

		$params = $this->params;
		$params->set('token', $token);

		$params = json_encode($params);

		$query = $db->getQuery(true)
			->update($db->quoteName('#__extensions'))
			->set($db->quoteName('params') . ' = ' . $db->quote($params))
			->where($db->quoteName('type') . ' = ' . $db->quote('component'))
			->where($db->quoteName('element') . ' = ' . $db->quote('com_unaapi'));

		try
		{
			$db->setQuery($query)->execute();
		}
		catch (Exception $e)
		{
			echo JText::sprintf('JLIB_DATABASE_ERROR_FUNCTION_FAILED', $e->getCode(), $e->getMessage()) . '<br />';

			return;
		}

		// Clean the cache
		$this->cleanCache('_system');
	}

	public function cleanCache($group = null, $clientId = 0)
	{
		parent::cleanCache('com_unaapi');
	}
}