<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\Model\BaseDatabaseModel;

/**
 * Script file of UNA API component
 */
class com_unaapiInstallerScript
{
        /**
         * method to install the component
         * $parent is the class calling this method
         *
         * @return void
         */
        function install($parent) 
        {
        	$db = JFactory::getDbo();

            $manifest = $parent->getManifest();
            $parent = $parent->getParent();
            $source = $parent->getPath("source");
             
            $installer = new JInstaller();
			
			$installed = array();
            
            // Install plugins
            foreach($manifest->plugins->plugin as $plugin) {
                $attributes = $plugin->attributes();
                $plg = $source . '/' . $attributes['folder'];
				$plugin = $attributes['plugin'];
				if ($installer->install($plg)) {
					$installed["$plugin"] = true;
				} else {
					$installed["$plugin"] = false;
				}
            }

            // create Push Notification field
			JLoader::register('FieldsModelField', JPATH_ADMINISTRATOR . '/components/com_fields/models/field.php');
			/** @var FieldsModelField $model */
			$model = BaseDatabaseModel::getInstance('Field', 'FieldsModel', array('ignore_request' => true));

            $query = $db->getQuery(true);
            $query->select('id')->from('#__fields')->where('note = ' . $db->q('UNA API'));
            $db->setQuery($query);

            $pn_string = '';

            if (!$db->loadResult()) {
				$data = array(
					'context' => 'com_content.article',
					'group_id' => 0,
					'title' => 'Push Notification',
					'label' => 'Push Notification',
					'default_value' => '',
					'type' => 'checkboxes',
					'note' => 'UNA API',
					'description' => 'Send push notification to mobile applications',
					'state' => 1,
					'params' => '',
					'fieldparams' => '{"options":{"options0":{"name":"Yes","value":"1"}}}',
					'language' => '*',
				);
				if ($model->save($data)) {
					$pn_string .= 'Push Notification field created<br />';
				}
            }
            
            $tableExtensions = $db->quoteName("#__extensions");
            $columnElement   = $db->quoteName("element");
            $columnType      = $db->quoteName("type");
            $columnEnabled   = $db->quoteName("enabled");
			
			if (isset($installed['unaapi']) && $installed['unaapi']) {
				// Enable plugins
				$db->setQuery(
					"UPDATE 
						$tableExtensions
					SET
						$columnEnabled=1
					WHERE
						$columnElement='unaapi'
					AND
						$columnType='plugin'"
				);
				
				$db->execute();
				
				echo '<div class="clearfix" style="margin-bottom: 20px;">
				<h1>Congratulations, you successfully installed UNA API component</h1>
				UNA API content plugin is also installed and enabled<br />
				' . $pn_string . '
				<br />
				<a href="index.php?option=com_unaapi">Proceed to UNA API control panel</a></div>';
			}
            
        }
 
        /**
         * method to uninstall the component
         * $parent is the class calling this method
         *
         * @return void
         */
        function uninstall($parent) 
        {
			$db = JFactory::getDBO();
            $tableExtensions = $db->quoteName("#__extensions");
            $columnElement   = $db->quoteName("element");
            $columnType      = $db->quoteName("type");

            // remove Push Notification field
            /*
            $query = $db->getQuery(true);
            $query->select('id')->from('#__fields')->where('note = ' . $db->q('UNA API'));
            $db->setQuery($query);
            if ($id = $db->loadResult()) {
				JLoader::register('FieldsModelField', JPATH_ADMINISTRATOR . '/components/com_fields/models/field.php');
				// @var FieldsModelField $model
				$model = BaseDatabaseModel::getInstance('Field', 'FieldsModel', array('ignore_request' => true));
				if ($model->delete($id)) {
					echo 'Push Notification field also removed<br />';
				}
            }
            */
					
			$db->setQuery(
				"SELECT extension_id, folder FROM 
					$tableExtensions
				WHERE
					$columnElement='unaapi'
				AND
					$columnType='plugin'"
			);
			
			if ($rows = $db->loadObjectList()) {
				foreach( $rows as $row ) {
					$id = $row->extension_id;
					// uninstall the plugin
					$installer = new JInstaller();
					$result	= $installer->uninstall( 'plugin', $id, 0 );
					if ($result) {
						echo 'UNA API '.$row->folder.' plugin also removed<br />';
					} else {
						echo 'UNA API '.$row->folder.' plugin could not be removed<br />Please remove this plugin manually<br />';
					}
				}
			} else {
				echo 'UNA API plugins could not be found<br />';
			}
			echo '<br />';
			//echo '<p>' . JText::_('COM_UNAAPI_UNINSTALL_TEXT') . '</p>';
        }
 
        /**
         * method to update the component
         * $parent is the class calling this method
         *
         * @return void
         */
        function update($parent) 
        {
			$this->install($parent);
			//echo '<p>' . JText::_('COM_UNAAPI_UPDATE_TEXT') . '</p>';
        }
 
        /**
         * method to run before an install/update/uninstall method
         * $parent is the class calling this method
         * $type is the type of change (install, update or discover_install)
         *
         * @return void
         */
        function preflight($type, $parent) 
        {
			if (defined('JVERSION')) {
				if (version_compare(JVERSION, '3.0.0') < 0) {
					JFactory::getApplication()->redirect('index.php?option=com_installer&view=install', 'This version of UNA API can not be installed on Joomla ' . JVERSION, 'error');
					return false;
				}
			}
			
			// delete possible remaining menu entries which can cause error building menus
			$db = JFactory::getDBO();
			
			$query = $db->getQuery(true);
			$query->delete();
			$query->from('#__menu');
			$query->where('client_id = 1 AND link LIKE '.$db->Quote('index.php?option=com_unaapi%'));
			
			$db->setQuery($query);
			$db->execute();

			//echo '<p>' . JText::_('COM_UNAAPI_PREFLIGHT_' . $type . '_TEXT') . '</p>';
        }
 
        /**
         * method to run after an install/update/uninstall method
         * $parent is the class calling this method
         * $type is the type of change (install, update or discover_install)
         *
         * @return void
         */
        function postflight($type, $parent) 
        {
			//echo '<p>' . JText::_('COM_UNAAPI_POSTFLIGHT_' . $type . '_TEXT') . '</p>';
        }
}