<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

defined('_JEXEC') or die;

use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Http\HttpFactory;
use Joomla\CMS\MVC\Model\BaseDatabaseModel;

JLoader::register( 'UnaApiHelper', JPATH_ADMINISTRATOR . '/components/com_unaapi/helpers/unaapi.php' );

/**
 * UNA API plugin
 */
class PlgContentUnaApi extends CMSPlugin
{
	protected $old_value;

	/**
	 * Content is passed by reference. Method is called before the content is saved.
	 *
	 * @param   string  $context  The context of the content passed to the plugin
	 * @param   object  $article  A JTableContent object
	 * @param   bool    $isNew    If the content is just about to be created
	 *
	 * @return  void
	 *
	 * @since   2.5
	 */
	public function onContentBeforeSave($context, $article, $isNew)
	{
		if ($context === 'com_content.article')
		{
			JLoader::register('FieldsHelper', JPATH_ADMINISTRATOR . '/components/com_fields/helpers/fields.php');
			$fields          = FieldsHelper::getFields($context, $article);
			foreach ($fields as $field) {
				if ($field->note == 'UNA API') {
					$this->old_value = $field->value;
				}
			}
		}
	}

	/**
	 *
	 * @param   string  $context  The context of the content passed to the plugin
	 * @param   object  $article  A JTableContent object
	 * @param   bool    $isNew    If the content has just been created
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	public function onContentAfterSave($context, $article, $isNew)
	{
		if ($context === 'com_content.article')
		{
			JLoader::register('UnaApiModelUnaApi', JPATH_ADMINISTRATOR . '/components/com_unaapi/models/unaapi.php');
			$model = BaseDatabaseModel::getInstance('UnaApi', 'UnaApiModel', array('ignore_request' => true));

			$value = 0;
			JLoader::register('FieldsHelper', JPATH_ADMINISTRATOR . '/components/com_fields/helpers/fields.php');
			$fields = FieldsHelper::getFields($context, $article);
			foreach ($fields as $field) {
				if ($field->note == 'UNA API') {
					$value = $field->value;
				}
			}
			if (!$this->old_value && $value)
			{
				// send push notification
				$token = $model->getTokenForDisplay();

				$url = 'https://getuna.app/api/v1/pn/send';

				$images = json_decode($article->images);
				if (isset($images->image_intro) && $images->image_intro) {
					$image = $images->image_intro;
				} else if (isset($images->image_fulltext) && $images->image_fulltext) {
					$image = $images->image_fulltext;
				}

				if ($image) {
					$image = '/' . UnaApiHelper::imgSafe($image);
				}

				$data = array(
					'articleId' => $article->id,
					'articleTitle' => $article->title,
					'articleDesc' => trim(strip_tags($article->introtext)),
					'imageUrl' => $image,
					'dominantColor' => '',
				);

				$http     = HttpFactory::getHttp();
				$headers = array(
					'Accept' => 'application/json',
					'Authorization' => 'Bearer ' . $token,
				);
				$response = $http->post($url, $data, $headers);

				if ($response->code != 200) {
					$this->loadLanguage();
					$body = json_decode($response->body);
					JFactory::getApplication()->enqueueMessage(JText::sprintf('PLG_CONTENT_UNAAPI_PUSH_NOTIFICATION_FAILED', $body->message), 'error');
					// reset the checkbox
					foreach ($fields as $field) {
						if ($field->note == 'UNA API') {
							$db = JFactory::getDbo();
							$query = $db->getQuery(true);
							$query->update('#__fields_values')->set('value = 0')->where('field_id = ' . $field->id);
							$db->setQuery($query);
							$db->execute();
						}
					}
				}
			}

			// clear cache
			$model->cleanCache();
		}
	}
}