<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

use Joomla\CMS\Component\ComponentHelper;

defined('_JEXEC') or die;

/**
 * UnaApi Controller
 *
 * @since  1.5
 */
class UnaApiController extends JControllerLegacy
{
	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 * Recognized key values include 'name', 'default_task', 'model_path', and
	 * 'view_path' (this list is not meant to be comprehensive).
	 *
	 * @since   3.0.1
	 */
	public function __construct($config = array())
	{
		// Set format to json
		//$document = \JFactory::getDocument();
		//$document = JFactory::getApplication()->getDocument();
		//$document->setType('json');

		parent::__construct($config);
	}

	public function execute($task)
	{
		// authenticate
		$response = $this->authenticate();

		if ($response && $response->status === JAuthentication::STATUS_SUCCESS) {
			return parent::execute($task);
		}

		$this->app->setHeader('status', 401);
		echo json_encode(
			array('message' => 'Unauthenticated.')
		);

		return false;
	}

	/**
	 * Method to display a view.
	 *
	 * @param   boolean  $cachable   If true, the view output will be cached.
	 * @param   boolean  $urlparams  An array of safe URL parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return  JController  This object to support chaining.
	 *
	 * @since   1.5
	 */
	public function display($cachable = false, $urlparams = false)
	{
		$cachable = true;

		/**
		 * Set the default view name and format from the Request.
		 * Note we are using a_id to avoid collisions with the router and the return page.
		 * Frontend is a bit messier than the backend.
		 */
		$id    = $this->input->getInt('a_id');
		$vName = $this->input->getCmd('view', 'categories');
		$this->input->set('view', $vName);

		$safeurlparams = array(
			'catid' => 'INT',
			'id' => 'INT',
			'cid' => 'ARRAY',
			'year' => 'INT',
			'month' => 'INT',
			'limit' => 'UINT',
			'limitstart' => 'UINT',
			'showall' => 'INT',
			'return' => 'BASE64',
			'filter' => 'STRING',
			'filter_order' => 'CMD',
			'filter_order_Dir' => 'CMD',
			'filter-search' => 'STRING',
			'print' => 'BOOLEAN',
			'lang' => 'CMD',
			'Itemid' => 'INT',
			'page' => 'UINT',
			'searchword' => 'STRING',
		);

		if ($vName === 'article')
		{
			if (ComponentHelper::getParams('com_content')->get('record_hits', 1) == 1)
			{
				// Get/Create the model
				JLoader::register( 'ContentModelArticle', JPATH_SITE . '/components/com_content/models/article.php' );
				if (!class_exists('ContentModelArticle')) {
					// Joomla 4
					$article_model = JFactory::getApplication()->bootComponent('com_content')->getMVCFactory()->createModel('Article', 'Site');
				} else {
					// Joomla 3
					$article_model = JModelLegacy::getInstance('ContentModelArticle');
				}

				$article_model->hit();
			}
		}

		parent::display($cachable, $safeurlparams);

		return $this;
	}

	/**
	 * This method should handle any authentication and report back to the subject
	 *
	 * @return  void | stdClass
	 *
	 * @since   3.0
	 */
	protected function authenticate() {
		$app         = \JFactory::getApplication();
		$input       = $app->input;
		$inputFilter = \JFilterInput::getInstance();
		$params = JComponentHelper::getParams('com_unaapi');

		$response = new stdClass();

		// Default response is authentication failure.
		$response->type          = 'Token';
		$response->status        = JAuthentication::STATUS_FAILURE;
		$response->error_message = JText::_('JGLOBAL_AUTH_FAIL');

		/**
		 * First look for an HTTP Authorization header with the following format:
		 * Authorization: Bearer <token>
		 * Do keep in mind that Bearer is **case-sensitive**. Whitespace between Bearer and the
		 * token, as well as any whitespace following the token is discarded.
		 */
		$authHeader  = $input->server->get('HTTP_AUTHORIZATION', '', 'string');
		$tokenString = '';

		// Apache specific fixes. See https://github.com/symfony/symfony/issues/19693
		if (
			empty($authHeader) && \PHP_SAPI === 'apache2handler'
			&& function_exists('apache_request_headers') && apache_request_headers() !== false
		) {
			$apacheHeaders = array_change_key_case(apache_request_headers(), CASE_LOWER);

			if (array_key_exists('authorization', $apacheHeaders)) {
				$authHeader = $inputFilter->clean($apacheHeaders['authorization'], 'STRING');
			}
		}

		if (substr($authHeader, 0, 7) == 'Bearer ') {
			$parts       = explode(' ', $authHeader, 2);
			$tokenString = trim($parts[1]);
			$tokenString = $inputFilter->clean($tokenString, 'BASE64');
		}

		if (empty($tokenString)) {
			$tokenString = $input->server->get('HTTP_X_JOOMLA_TOKEN', '', 'string');
		}

		// No token: authentication failure
		if (empty($tokenString)) {
			return;
		}

		// The token is a base64 encoded string. Make sure we can decode it.
		$authString = @base64_decode($tokenString);

		if (empty($authString) || (strpos($authString, ':') === false)) {
			return;
		}

		/**
		 * Deconstruct the decoded token string to its three discrete parts: algorithm, user ID and
		 * HMAC of the token string saved in the database.
		 */
		$parts = explode(':', $authString, 2);

		if (count($parts) != 2) {
			return;
		}

		list($algo, $tokenHMAC) = $parts;

		/**
		 * Verify the HMAC algorithm requested in the token string is allowed
		 */
		$allowedAlgo = in_array($algo, array('sha256'));

		if (!$allowedAlgo) {
			return;
		}

		/**
		 * Calculate the reference token data HMAC
		 */
		try {
			$siteSecret = $app->get('secret');
		} catch (\Exception $e) {
			return;
		}

		// An empty secret! What kind of monster are you?!
		if (empty($siteSecret)) {
			return;
		}

		$tokenSeed = $params->get('token', '');
		if (empty($tokenSeed)) {
			return;
		}

		$referenceTokenData = $tokenSeed;
		$referenceTokenData = empty($referenceTokenData) ? '' : $referenceTokenData;
		$referenceTokenData = base64_decode($referenceTokenData);
		$referenceHMAC      = hash_hmac($algo, $referenceTokenData, $siteSecret);

		// Do the tokens match? Use a timing safe string comparison to prevent timing attacks.
		$hashesMatch = JCrypt::timingSafeCompare($referenceHMAC, $tokenHMAC);

		/**
		 * Can we log in?
		 *
		 * DO NOT concatenate in a single line. Due to boolean short-circuit evaluation it might
		 * make timing attacks possible. Using separate lines of code with the previously calculated
		 * boolean value to the right hand side forces PHP to evaluate the conditions in
		 * approximately constant time.
		 */

		// We need non-empty reference token data (the user must have configured a token)
		$canLogin = !empty($referenceTokenData);

		// The token HMAC hash coming into the request and our reference must match.
		$canLogin = $hashesMatch && $canLogin;

		/**
		 * DO NOT try to be smart and do an early return when either of the individual conditions
		 * are not met. There's a reason we only return after checking all three conditions: it
		 * prevents timing attacks.
		 */
		if (!$canLogin) {
			return;
		}

		// Update the response to indicate successful login
		$response->status        = JAuthentication::STATUS_SUCCESS;
		$response->error_message = '';

		return $response;
	}
}