<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

use Joomla\Utilities\ArrayHelper;

defined('_JEXEC') or die;

/**
 * Frontpage Component Model
 *
 * @since  1.5
 */
class UnaApiModelArticles extends UnaArticlesModel
{
	/**
	 * Model context string.
	 *
	 * @var		string
	 */
	public $_context = 'com_content.articles';

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   The field to order on.
	 * @param   string  $direction  The direction to order on.
	 *
	 * @return  void
	 *
	 * @since   1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		parent::populateState($ordering, $direction);

		$app = JFactory::getApplication('site');
		$catid  = $app->input->getInt('catid');
		$filter  = $app->input->getString('filter');

		// Load the parameters. Merge Global and component params into new object
		$params = $this->state->params;

		$contentParams = JComponentHelper::getParams('com_content');

		$mergedParams = clone $contentParams;
		$mergedParams->merge($params);

		$this->setState('params', $mergedParams);

		if ($catid) {
			$this->setState('filter.category_id', $catid);
			$this->setState('filter.subcategories', true);  // include subcategories
		}

		$this->setState('filter.published', 1);

		if ($filter == 'popular') {
			$this->setState('list.ordering', 'a.hits');

			$relative_date = $params->get('relative_date', 0);
			if ($relative_date) {
				$this->setState('filter.date_filtering', 'relative');
				$this->setState('filter.relative_date', $relative_date);
				$this->setState('filter.date_field', 'a.publish_up');
			}
		} else {
			$this->setState('list.ordering', 'a.publish_up');
		}

		$this->setState('list.direction', 'DESC');

		$limit = $app->input->getInt('limit', 20);
		$this->setState('list.limit', $limit);

		$page = $app->input->get('page', 0, 'uint');

		$limitstart = 0;
		if ($page && $page > 1) {
			$limitstart = ($page - 1) * $limit;
		}
		$this->setState('list.start', $limitstart);
	}

	/**
	 * Get the master query for retrieving a list of articles subject to the model state.
	 *
	 * @return  JDatabaseQuery
	 *
	 * @since   1.6
	 */
	protected function getListQuery()
	{
		$app        = JFactory::getApplication();
		$db         = $this->getDbo();
		$keyword    = urldecode($app->input->getString('searchword'));

		$query = parent::getListQuery();

		// Include categories
		/*
		$params = $this->getState('params');
		$includeCategories = $params->get('include_categories', array());

		if (!empty($includeCategories)) {

			$query->where('a.catid IN (' . implode(',', ArrayHelper::toInteger($includeCategories)) . ')');

		}
		*/

		// Search: Filter by a keyword
		if ($keyword) {
			$query->where('(a.title LIKE ' . $db->q('%'.$keyword.'%') . ' OR a.introtext LIKE ' . $db->q('%'.$keyword.'%') . ' OR a.fulltext LIKE ' . $db->q('%'.$keyword.'%') . ')');
		}

		return $query;
	}
}