<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;

defined('_JEXEC') or die;

/**
 * Frontpage View class
 *
 * @since  1.5
 */
class UnaApiViewArticle extends JViewLegacy
{
	/**
	 * Execute and display a template script.
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  mixed  A string if successful, otherwise an Error object.
	 */
	public function display($tpl = null)
	{
		$article = array();

		// get article
		JLoader::register( 'ContentModelArticle', JPATH_SITE . '/components/com_content/models/article.php' );
		if (!class_exists('ContentModelArticle')) {
			// Joomla 4
			$article_model = JFactory::getApplication()->bootComponent('com_content')->getMVCFactory()->createModel('Article', 'Site');
		} else {
			// Joomla 3
			$article_model = JModelLegacy::getInstance('ContentModelArticle');
		}

		if ($item = $article_model->getItem()) {

			$item->slug = $item->alias ? ($item->id . ':' . $item->alias) : $item->id;

			$thumb = $image = $image_desc = '';
			$images = json_decode($item->images);

			if (isset($images->image_intro) && $images->image_intro) {
				$thumb = $images->image_intro;
			}
			if (isset($images->image_fulltext) && $images->image_fulltext && is_file($images->image_fulltext)) {
				$image = $images->image_fulltext;
			}
			if (isset($images->image_fulltext_caption) && $images->image_fulltext) {
				$image_desc = $images->image_fulltext_caption;
			}

			if ($thumb) {
				$thumb = JUri::base() . UnaApiHelper::imgSafe($thumb);
			}

			if ($image) {
				$image = JUri::base() . UnaApiHelper::imgSafe($image);
			}

			if (!$image && $thumb) {
				$image = $thumb;
			}

			$item->text = $item->fulltext;

			// Process the content plugins.
			JPluginHelper::importPlugin('content');
			if (!class_exists('JEventDispatcher')) {
				// Joomla 4
				Factory::getApplication()->triggerEvent('onContentPrepare', array('com_unaapi.article', &$item, &$item->params, 0));
			} else {
				$dispatcher = JEventDispatcher::getInstance();
				$dispatcher->trigger('onContentPrepare', array('com_unaapi.article', &$item, &$item->params, 0));
			}

			$article['id'] = $item->id;
			$article['category'] = $item->category_title;
			$article['categoryId'] = $item->catid;
			$article['title'] = $item->title;
			$article['intro'] = trim(html_entity_decode(strip_tags($item->introtext)), " \t\n\r\0\x0B\xC2\xA0");
			$article['text'] = UnaApiHelper::sef($item->text);
			$article['url'] = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catid, $item->language), true, JRoute::TLS_IGNORE, true);
			$article['datePublished'] = HtmlHelper::date($item->publish_up, 'Y-m-d H:i:s', null);
			$article['gallery'] = array('photo' => 0, 'video' => 0);
			$article['comments'] = array('show' => 0, 'count' => 0);
			$article['photos'] = array(
				array(
					'main' => $image,
					'thumb' => $thumb,
					'description' => $image_desc,
				)
			);
			$article['videos'] = array();
		}

		echo json_encode($article);
	}
}