<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;

defined('_JEXEC') or die;

/**
 * Frontpage View class
 *
 * @since  1.5
 */
class UnaApiViewArticles extends JViewLegacy
{
	protected $state = null;

	protected $items = null;

	protected $pagination = null;

	/**
	 * Execute and display a template script.
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  mixed  A string if successful, otherwise an Error object.
	 */
	public function display($tpl = null)
	{
		$articles = array();

		$state      = $this->get('State');
		$items      = $this->get('Items');
		$pagination = $this->get('Pagination');

		// Flag indicates to not add limitstart=0 to URL
		$pagination->hideEmptyLimitstart = true;

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			JError::raiseWarning(500, implode("\n", $errors));

			return false;
		}

		foreach ($items as $item)
		{
			$item->slug = $item->alias ? ($item->id . ':' . $item->alias) : $item->id;

			$thumb = $image = '';
			$images = json_decode($item->images);
			if (isset($images->image_intro) && $images->image_intro) {
				$image = $images->image_intro;
			} else if (isset($images->image_fulltext) && $images->image_fulltext) {
				$image = $images->image_fulltext;
			}

			if ($image) {
				$thumb = JUri::base() . UnaApiHelper::imgSafe($image);
			}

			$article = array();

			$article['id'] = $item->id;
			$article['title'] = $item->title;
			$article['category'] = $item->category_title;
			$article['url'] = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catid, $item->language), true, JRoute::TLS_IGNORE, true);
			$article['datePublished'] = HtmlHelper::date($item->publish_up, 'Y-m-d H:i:s', null);
			$article['dominantColor'] = '';
			$article['thumb'] = $thumb;
			$article['gallery'] = array(
				'photo' => 0,
				'video' => 0
			);
			$article['comments'] = array(
				'show' => 0,
				'count' => 0
			);

			$articles[] = $article;
		}

		echo json_encode($articles);
	}
}