<?php
/*
 * @package		UNA API
 * @copyright	Copyright (C) 2023 Emir Sakic, http://www.sakic.net. All rights reserved.
 * @license		GNU/GPL, see LICENSE.TXT
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 */

use Joomla\CMS\Factory;

defined('_JEXEC') or die;

/**
 * Frontpage View class
 *
 * @since  1.5
 */
class UnaApiViewCategories extends JViewLegacy
{
	/**
	 * Execute and display a template script.
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  mixed  A string if successful, otherwise an Error object.
	 */
	public function display($tpl = null)
	{
		$category_list = array();

		// get categories
		JLoader::register( 'ContentModelCategories', JPATH_SITE . '/components/com_content/models/categories.php' );
		if (!class_exists('ContentModelCategories')) {
			// Joomla 4
			$categories_model = JFactory::getApplication()->bootComponent('com_content')->getMVCFactory()->createModel('Categories', 'Site');
		} else {
			// Joomla 3
			$categories_model = JModelLegacy::getInstance('ContentModelCategories');
		}

		$params = JComponentHelper::getParams('com_unaapi');
		$includeCategories = $params->get('include_categories', array());

		$categories = $categories_model->getItems(true);

		foreach ($categories as $category) {
			if (in_array($category->id, $includeCategories)) {
				$category_list[] = array(
					'category' => $category->title,
					'categoryId' => (int) $category->id
				);
			}
		}

		echo json_encode($category_list);
	}
}